@@ -2,10 +2,11 @@ package DBIx::Class::Indexed;
 
 use strict;
 use warnings;
+use Module::Load;
 
 use base qw( DBIx::Class );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->mk_classdata( _indexer                => undef );
 __PACKAGE__->mk_classdata( indexer_connection_info => {} );
@@ -95,9 +96,7 @@ sub indexer {
         my $name    = $self->indexer_package;
         my $package = "DBIx::Class::Indexer::$name";
         
-        # ensure the indexer package is loaded
-        eval "require $package";
-        die "Failed to load indexer: $@" if $@;
+        load $package;
 
         $indexer = $package->new( $self->indexer_connection_info, ref $self );
         $schema->{ _indexers }->{ $key } = $indexer;
@@ -238,7 +237,7 @@ sub register_field {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Adam Paynter
+Copyright 2006 by Adam Paynter, 2007-2011 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
